summaryrefslogtreecommitdiffstats
path: root/kdecore/kaccelmanager_private.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kdecore/kaccelmanager_private.h
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdecore/kaccelmanager_private.h')
-rw-r--r--kdecore/kaccelmanager_private.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kdecore/kaccelmanager_private.h b/kdecore/kaccelmanager_private.h
index fbb5d1857..cd3f30a12 100644
--- a/kdecore/kaccelmanager_private.h
+++ b/kdecore/kaccelmanager_private.h
@@ -32,7 +32,7 @@ class TQWidgetStack;
/**
* A string class handling accelerators.
*
- * This class contains a string and knowledge about accelerators.
+ * This class tqcontains a string and knowledge about accelerators.
* It keeps a list weights, telling how valuable each character
* would be as an accelerator.
*
@@ -81,7 +81,7 @@ typedef TQValueList<KAccelString> KAccelStringList;
/**
- * This class encapsulates the algorithm finding the 'best'
+ * This class encapsulates the algorithm tqfinding the 'best'
* distribution of accelerators in a hierarchy of widgets.
*
* @author Matthias Hoelzer-Kluepfel <mhk@kde.org>
@@ -113,8 +113,8 @@ public:
STANDARD_ACCEL = 300
};
- /// Method to call to find the best distribution of accelerators.
- static void findAccelerators(KAccelStringList &result, TQString &used);
+ /// Method to call to tqfind the best distribution of accelerators.
+ static void tqfindAccelerators(KAccelStringList &result, TQString &used);
};
@@ -131,7 +131,7 @@ class TQPopupMenu;
* @author Matthias Hoelzer-Kluepfel <mhk@kde.org>
*/
-class KPopupAccelManager : public QObject
+class KPopupAccelManager : public TQObject
{
Q_OBJECT
@@ -154,7 +154,7 @@ private:
void calculateAccelerators();
- void findMenuEntries(KAccelStringList &list);
+ void tqfindMenuEntries(KAccelStringList &list);
void setMenuEntries(const KAccelStringList &list);
TQPopupMenu *m_popup;
@@ -164,7 +164,7 @@ private:
};
-class QWidgetStackAccelManager : public QObject
+class QWidgetStackAccelManager : public TQObject
{
Q_OBJECT